@@ -9,10 +9,10 @@
 #
 package Config::Model::Backend::OpenSsh::Ssh ;
 BEGIN {
-  $Config::Model::Backend::OpenSsh::Ssh::VERSION = '1.215';
+  $Config::Model::Backend::OpenSsh::Ssh::VERSION = '1.216';
 }
 
-use Moose ;
+use Any::Moose ;
 extends "Config::Model::Backend::OpenSsh" ;
 
 use Carp ;
@@ -204,6 +204,8 @@ sub write_forward {
 }
 1;
 
+no Any::Moose;
+
 __END__
 
 =head1 NAME
